@@ -73,7 +73,7 @@ fail_insert:
 
 static int compare_inum(const void *lhs, const void *rhs)
 {
-	sqfs_u32 l = *((sqfs_u32 *)lhs), r = *((sqfs_u32 *)rhs);
+	sqfs_u32 l = *((const sqfs_u32 *)lhs), r = *((const sqfs_u32 *)rhs);
 
 	return l < r ? -1 : (l > r ? 1 : 0);
 }
