@@ -11,7 +11,7 @@
 
 static int key_compare(const void *a, const void *b)
 {
-	return *((sqfs_s32 *)a) - *((sqfs_s32 *)b);
+	return *((const sqfs_s32 *)a) - *((const sqfs_s32 *)b);
 }
 
 static size_t count_nodes_dfs(rbtree_node_t *n)
